==> qt-creator-opensource-src-4.1.0.zip: qt-creator-opensource-src-4.1.0/src/tools/clangbackend/ipcsource/commandlinearguments.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <utf8stringvector.h>

#include <vector>

namespace ClangBackEnd {

class CommandLineArguments
{
public:
    CommandLineArguments(const char *filePath,
                         const std::vector<const char *> &projectPartArguments,
                         const Utf8StringVector &fileArguments,
                         bool addVerboseOption);

    const char * const *data() const;
    int count() const;
    const char * at(int position) const;

    void print() const;

private:
    Utf8String m_nativeFilePath;
    std::vector<const char *> m_arguments;
};

} // namespace ClangBackEnd

==> qt-creator-opensource-src-4.2.2.zip: qt-creator-opensource-src-4.2.2/src/tools/clangbackend/ipcsource/commandlinearguments.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <utf8stringvector.h>

#include <vector>

namespace ClangBackEnd {

class CommandLineArguments
{
public:
    CommandLineArguments(const char *filePath,
                         const Utf8StringVector &projectPartArguments,
                         const Utf8StringVector &fileArguments,
                         bool addVerboseOption);

    const char * const *data() const;
    int count() const;
    const char * at(int position) const;

    void print() const;

private:
    Utf8String m_nativeFilePath;
    std::vector<const char *> m_arguments;
};

} // namespace ClangBackEnd
